
/* 
 * This is a simple two-servo "harmonograph" drawing machine. 
 * It uses two pots as inputs that set the relative speed and direction
 * of the servos. The servos are "continuous rotation" type servos
 * that spin instead of move back and forth. A continuous rotation 
 * servo should stop when the value written to it is somewhere around
 * 90 (plus or minus a few). Larger numbers will spin faster in one
 * direction, and smaller numbers will spin faster in the other. 
 */
 
#include <Servo.h>  // Include the library code
Servo servo1, servo2; // create two servo objects
// and define pins that they'll attach to
int servo1Pin = 8; 
int servo2Pin = 9; 

// These variables hold the value of the analog sensors. 
// These sensors can be pots, light sensors, etc. 
int sensorPin1 = A0;    // The pins they're connected to
int sensorPin2 = A1; 
int sensorValue1 = 0;   // Variables to hold their values
int sensorValue2 = 0; 

void setup() { 
  servo1.attach(servo1Pin);  // attach each of the servo control wires to 
  servo2.attach(servo2Pin); // different pins. All the servos can share 
} 
 
void loop() { 

  // First read the sensor values and map them to the servo
  // range. The pots should be roughly full range and return 
  // values from around 0 to aroun 1023 (give or take a few). 
  // You'll likely want to restrict the output range that you 
  // send to the servos to keep them from moving too fast. 
  sensorValue1 = analogRead(sensorPin1); 
  sensorValue1 = map(sensorValue1, 0, 1023, 90, 98); 
  sensorValue2 = analogRead(sensorPin2); 
  sensorValue2 = map(sensorValue2, 0, 1023, 90, 98); 
  
  // Now write those values to the servos
  servo1.write(sensorValue1);            
  servo2.write(sensorValue2); 
  
  delay(30);                   // remember to wait for the servos to move 
} 

